@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "fontify-face" "1.1.0"
+(define-package "fontify-face" "20251111.1121"
   "Fontify symbols representing faces with that face."
-  '((emacs "24"))
+  '((emacs "25.1"))
   :url "https://github.com/Fuco1/fontify-face"
-  :commit "fc3325c98427523d86f0b411e0515cec51ac3d8a"
-  :revdesc "fc3325c98427"
+  :commit "b975c764b6e9e070c7673317146b4d345ec83ef8"
+  :revdesc "b975c764b6e9"
   :keywords '("faces")
   :authors '(("Matúš Goljer" . "matus.goljer@gmail.com"))
   :maintainers '(("Matúš Goljer" . "matus.goljer@gmail.com")))
